import React from "react";
import ReactNative, { View, Platform } from "react-native";
import PropTypes from "prop-types";

export default class Alert extends React.Component {
  render = () => {
    let { type, style } = this.props,
      backgroundColor = "fefefe";

    switch (type) {
      case "primary":
        backgroundColor = "#cce5ff";
        break;
      case "secondary":
        backgroundColor = "#e2e3e5";
        break;
      case "success":
        backgroundColor = "#d4edda";
        break;
      case "danger":
        backgroundColor = "#f8d7da";
        break;
      case "warning":
        backgroundColor = "#fff3cd";
        break;
      case "info":
        backgroundColor = "#d1ecf1";
        break;
      case "light":
        backgroundColor = "#fefefe";
        break;
      case "dark":
        backgroundColor = "#d6d8d9";
        break;
      default:
        break;
    }

    return (
      <View
        style={[
          {
            padding: 5,
            width: "100%",
            borderRadius: 4,
            backgroundColor,
            ...Platform.select({
              ios: {
                shadowColor: "#000",
                shadowOffset: { width: 0, height: 0.5 },
                shadowOpacity: 0.8,
                shadowRadius: 2
              },
              android: {
                elevation: 0.5
              }
            })
          },
          style
        ]}
      >
        {this.props.children}
      </View>
    );
  };
}

Alert.propTypes = {
  type: PropTypes.string,
  style: ReactNative.ViewPropTypes.style
};
